use strict;
use warnings;
use Test::More tests => 1;

BEGIN {
	use_ok( 'POE::Component::AI::MegaHAL' );
}

diag( "Testing POE::Component::AI::MegaHAL $POE::Component::AI::MegaHAL::VERSION, POE-$POE::VERSION, Perl $], $^X" );
